#
# spec file for package gitlint
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gitlint
Version:        0.13.1
Release:        bp154.1.20
Summary:        Git commit message linter checking
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jorisroovers/%{name}
Source:         https://pypi.io/packages/source/g/%{name}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE relax-requirements.patch -- relax requirements to work with openSUSE
Patch0:         relax-requirements.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-arrow >= 0.10.0
Requires:       python-click >= 6.7
Requires:       python-sh >= 1.12.14
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Great for use as a commit-msg git hook or as part of your gating script in
a CI/CD pipeline (e.g. jenkins). Many of the gitlint validations are based
on well-known community standards, others are based on checks that we've
found useful throughout the years. Gitlint has sane defaults, but you can
also easily customize it to your own liking.

%prep
%setup -q
%patch0 -p1

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/%{name}
%fdupes %{buildroot}%{_prefix}

%post
%python_install_alternative gitlint

%postun
%python_uninstall_alternative gitlint

%files %{python_files}
%license LICENSE
%{python_sitelib}/*
%python_alternative %{_bindir}/gitlint

%changelog
* Wed Jan 27 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Fix filelist: do not use %%{name}, as python single-spec rewrites
  the value 'as needed', interfering in this case.
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.13.1:
  * Patch to enable --staged flag for pre-commit.
  * Minor doc updates (#109)
  Revert Commits are now recognized and ignored by default (#99)
  - -staged flag: gitlint can now detect meta-data (such as author details, changed files, etc) of staged/pre-commits. Useful when you use gitlint's commit-msg hook or precommit (#105)
  * New branch properties on GitCommit and GitContext, useful when writing your own user-defined rules: commit.branches and commit.context.current_branch (#108)
  * Python 3.8 support
  * Python 3.4 no longer supported. Python 3.4 has reached EOL and an increasing
  * Gitlint no longer crashes when acting on empty repositories (this only occurred in specific circumstances).
  * Under-the-hood: dependencies updated, unit and integration test improvements, migrated from TravisCI to Github Actions.
* Thu Jul  4 2019 Rick Salevsky <rick.salevsky@suse.com>
- Correct download target URL and fix relax-requirements.patch
* Tue Jul  2 2019 Rick Salevsky <rick.salevsky@suse.com>
- Update to v0.11.0
  * add relax-requirements.patch to make it work with openSUSE
* Thu Jun 22 2017 mpluskal@suse.com
- Install LICENSE as well
- Use update alternatives
- Drop parts of description which are not relevant to package
* Thu Mar  9 2017 okurz@suse.com
- Initial submission
